TableExtractor class

Constructors

TableExtractor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseHtmlTable(String htmlString) List<Map<String, String>>
parseTextTable(String text, {String separator = '-'}) List<Map<String, String>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited